.. krakenex documentation master file, created by
   sphinx-quickstart on Sat Apr 16 20:02:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

krakenex documentation
======================

.. toctree::
   :maxdepth: 4
   

      

Classes and methods
-------------------
  
.. automodule:: krakenex
   :members: API, Connection
   :special-members:
   :private-members:


